@@ -354,7 +354,8 @@ class Graph:
 
         root = threading.Thread(target=root_cell.execute)
 
-        std_file_out = root_cell.name
+        std_file_out = "<" + root_cell.name + ">\n"
+        print("<" + root_cell.name + ">")
 
         root.start()
         root.join()
@@ -372,6 +373,8 @@ class Graph:
 
                 neighbor = threading.Thread(target=neighbor_cell.execute)
 
+                print("<" + neighbor_cell.name + ">")
+
                 neighbor.start()
                 processes.append(neighbor)
 
@@ -425,7 +428,7 @@ class Graph:
         if self.parent.std_capture.getvalue():
             txtout += "<!--SATYRN_DCO_START-->\n"
             txtout += self.parent.std_capture.getvalue()
-            txtout += "<execution complete>\n<!--SATYRN_DCO_END-->"
+            txtout += "\n<!--SATYRN_DCO_END-->"
 
         return txtout
 
